package cz.frantovo.hrisniciSpameri;

import cz.frantovo.hrisniciSpameri.dao.CilDAO;
import cz.frantovo.hrisniciSpameri.dao.SouhrnDAO;
import cz.frantovo.hrisniciSpameri.dto.Cil;
import cz.frantovo.hrisniciSpameri.dto.Souhrn;
import java.io.Serializable;
import java.sql.Date;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Collection;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * Beana zprostředkovávající denní souhrn hříšníků.
 * @author fiki
 */
public class DenniSouhrn implements Serializable {

    private static final long serialVersionUID = 7932392366943861342L;
    private static final Logger log = Logger.getLogger(DenniSouhrn.class.getName());
    private static String formatDataVzor = "yyyy-MM-dd";
    public static DateFormat formatData = new SimpleDateFormat(formatDataVzor);
    private Date den;
    private int cil;

    public String getDenString() {
        return formatData.format(getDen());
    }

    public Date getDen() {
        if (den == null) {
            nastavVychoziDen();
        }
        return den;
    }

    public void setDen(Date den) {
        if (den == null) {
            nastavVychoziDen();
        } else {
            this.den = den;
        }
        log.log(Level.FINE, "Den nastaven na: " + formatData.format(den));
    }

    public void setDenString(String den) {
        if (den == null) {
            nastavVychoziDen();
        }

        try {
            this.den = new Date(formatData.parse(den).getTime());
        } catch (ParseException e) {
            log.log(Level.FINE, "Chybně zadané datum: " + den, e);
            nastavVychoziDen();
        }
    }

    public void setCilString(String cil) {
        try {
            this.cil = Integer.parseInt(cil);
        } catch (Exception e) {
            this.cil = 0;
        }
    }

    public void setCil(int cil) {
        this.cil = cil;
    }

    public String getCilString() {
        return String.valueOf(cil);
    }

    public int getCil() {
        return cil;
    }

    private void nastavVychoziDen() {
        log.log(Level.FINE, "Nastavuji den na výchozí hodnotu.");
        setDen(SouhrnDAO.getVychoziDen());
    }

    public Collection<Souhrn> getSouhrn() {
        Collection<Souhrn> souhrn = new SouhrnDAO().getSouhrn(den, null, cil);

        /** ne všechno musíme posílat do JSP vrstvy */
        for (Souhrn s : souhrn) {
            s.getCil().setDatabaze(null);
            s.getCil().setSelekt(null);
        }

        return souhrn;
    }

    /**
     * @return Seznam všech cílů. Ale bez těchto hodnot: databáze a selekt.
     */
    public Collection<Cil> getSeznamCilu() {
        Collection<Cil> cile = new CilDAO().getCile();

        /** ne všechno musíme posílat do JSP vrstvy */
        for (Cil c : cile) {
            c.setDatabaze(null);
            c.setSelekt(null);
        }

        return cile;
    }
}
